use std::path::{Path, PathBuf};

#[derive(Clone, Debug, PartialEq)]
pub enum VcsClient {
    Noop {},
    Git { source: PathBuf },
}

impl VcsClient {
    pub fn new_noop() -> VcsClient {
        Self::Noop {}
    }
    pub fn new_git(path: &Path) -> anyhow::Result<VcsClient> {
        if !path.to_path_buf().join(".git").exists() {
            anyhow::bail!("git directory not found in: {}", path.display().to_string())
        }

        Ok(Self::Git {
            source: path.to_path_buf(),
        })
    }
}
